#!/usr/bin/perl -w

#
#   STEP 2: Mask the rRNAs in the complete genomes fasta files
#           (This script is called by step-2-mask-rrna.sh)
#
#   script: Use perl regular expressions to mask all 
#           rRNAs in all.fna using all.rrna.fna
#
#   contact: evguenia.kopylova@lifl.fr
#
#   date   : March 2012
#

use strict;
use warnings;

# check the input arguments
if ($#ARGV != 2 )
{
	print "usage: maskrrnas.pl genometomask startpos length\n";
	exit;
}

# file with genome to mask
my $genometomask=$ARGV[0];

# start position of the mask
my $startpos=$ARGV[1];

# length of the mask
my $length=$ARGV[2];

my ($tag,$genome);

my $mask="N" x $length;

# open the genome fasta file
open(INPUTGEN, "+< $genometomask") or die "opening: $!";

# mask the genome
while(<INPUTGEN>)
{
	# the tag
	if(/^>/)
	{
		$tag = $_; 	
	}
	# the genome
	else	
	{
		$genome = $_;
		$genome =~ substr($genome,$startpos,$length,$mask);
	}
}

# write the line back to the file
seek(INPUTGEN,0,0) or die "seeking: $!";
print INPUTGEN "$tag$genome" or die "printing: $!";
truncate(INPUTGEN,tell(INPUTGEN))  or die "truncating: $!";
close(INPUTGEN) or die "closing: $!";




