#!/bin/sh

#
#   STEP 2 : Mask the rRNAs in the complete genomes fasta files
#            (STEP 1 must be completed, run step-1-locate-rrna.sh)
#
#   script : Using the all.rrna.fna extracted rRNAs, their
#            positions on the complete sequence and their lengths,
#            we find their existence in the complementary complete
#            sequence and mask them with N's. We also mask an additional
#            150 nucleotides from both ends of the rRNA sequence
#            to cover any partial rRNA sequences.
#			 file source ftp://ftp.ncbi.nlm.nih.gov/genomes/Bacteria/all.fna.tar.gz
#
#   note:    The perl script step-2-mask-rrna.pl is called by step-2-mask-rrna.sh,
#            please make sure they are in the same folder, or the path to
#            step-2-mask-rrna.pl is given in the MASKPERL variable below.
#
#   contact: evguenia.kopylova@lifl.fr
#
#   date   : March 2012
#

# path to all.fna
XSTK="all.fna"
# path to all.rrna.fna (folder created in step-1-locate-rrna.sh)
RRNAS="all.rrna.fna"
# path to NEW folder containing masked all.fna
OUT="all.masked.fna"
# path to perl file step-2-mask-rrna.pl
MASKPERL="step-2-mask-rrna.pl"

STARTPOS=0

# for each bacterial genome all.fna file
for FOLDER in $XSTK/*
do
	# make a folder for the output masked files
	FOLDERBASE=$(basename $FOLDER)
	mkdir $OUT/$FOLDERBASE

	# for each fasta file 
	for FILE in $FOLDER/*.fna
	do
		# path to complementary rRNAs folder
		RRNASFILE=$RRNAS/$FOLDERBASE/$(basename $FILE)

		# rRNAs file is not empty, mask the rRNAs on bacterial genome
		if [ -s "$RRNASFILE" ]
		then
			GENOMETOMASK=$OUT/$FOLDERBASE/$(basename $(basename $FILE) .fna).mask.fna

			# make the all.fna fasta entry linear (no breaks in sequence)
			awk '/^>/ {printf("\n%s\n",$0);next; } { printf("%s",$0);}  END {printf("\n");}' < $FILE \
		        | egrep -v '^$' \
		        | tr "\t" "\n" > $GENOMETOMASK

			# for each rRNA to mask 
			while read RRNA
			do
				case "$RRNA" in
					'>'*) 	# the position on the bacterial genome where the rRNA begins (using string operators)
						STARTPOS=`expr ${RRNA##*_} - 150`
						continue ;;
				   	   *)   ;;
				esac

				# create the mask of N's
				RRNALENGTH=`expr length "$RRNA" + 150`

				# mask the one line genome 
				perl $MASKPERL $GENOMETOMASK $STARTPOS $RRNALENGTH
					
			done < "$RRNASFILE"

			# add a new line after each 70 nucleotides in the genome
			sed -i -e "2,$ s/.\{70\}/&\n/g" $GENOMETOMASK
		fi
	done
done


